@@ -33,6 +33,7 @@
 #  define KWALLET_DECL_DEPRECATED_NO_EXPORT KWALLET_NO_EXPORT KWALLET_DECL_DEPRECATED
 #endif
 
+/* NOLINTNEXTLINE(readability-avoid-unconditional-preprocessor-if) */
 #if 0 /* DEFINE_NO_DEPRECATED */
 #  ifndef KWALLET_NO_DEPRECATED
 #    define KWALLET_NO_DEPRECATED
@@ -84,7 +85,7 @@
 #define KWALLET_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KWALLET_NO_DEPRECATED
-#  define KWALLET_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56f00
+#  define KWALLET_DISABLE_DEPRECATED_BEFORE_AND_AT 0x57400
 #endif
 #ifdef KWALLET_NO_DEPRECATED_WARNINGS
 #  define KWALLET_DEPRECATED_WARNINGS_SINCE 0
@@ -94,7 +95,7 @@
 #  ifdef KWALLET_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KWALLET_DEPRECATED_WARNINGS_SINCE KWALLET_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KWALLET_DEPRECATED_WARNINGS_SINCE 0x56f00
+#    define KWALLET_DEPRECATED_WARNINGS_SINCE 0x57400
 #  endif
 #endif
 
